==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/outputs/AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property csv Mapping information when the record format uses delimiters.
 * See CSV Mapping Parameters below for more details.
 * @property json Mapping information when JSON is the record format on the streaming source.
 * See JSON Mapping Parameters below for more details.
 */
public data class AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters(
    public val csv: AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersCsv? =
        null,
    public val json: AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJson? =
        null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.kinesis.outputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters):
            AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters =
            AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters(
                csv = javaType.csv().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.kinesis.kotlin.outputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersCsv.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                json = javaType.json().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.kinesis.kotlin.outputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJson.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/outputs/AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property csv Mapping information when the record format uses delimiters.
 * See CSV Mapping Parameters below for more details.
 * @property json Mapping information when JSON is the record format on the streaming source.
 * See JSON Mapping Parameters below for more details.
 */
public data class AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters(
    public val csv: AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersCsv? =
        null,
    public val json: AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJson? =
        null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.kinesis.outputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters): AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters =
            AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters(
                csv = javaType.csv().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.kinesis.kotlin.outputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersCsv.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                json = javaType.json().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.kinesis.kotlin.outputs.AnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJson.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
